@@ -29,9 +29,7 @@
 #  define AKONADI_IGNORE_DEPRECATED_WARNINGS
 #endif
 
-namespace Akonadi
-{
-
+namespace Akonadi {
 /**
  * A flat self-updating message model.
  * @deprecated Subclass Akonadi::EntityTreeModel instead. An example can be seen in AkonadiConsole,
@@ -63,7 +61,7 @@ public:
     /**
       Deletes the message model.
     */
-    virtual ~MessageModel();
+    ~MessageModel() override;
 
     /**
       Reimplemented from QAbstractItemModel.
@@ -90,7 +88,6 @@ public:
      */
     QStringList mimeTypes() const override;
 };
-
 }
 
 #endif
